# python-aio-quakeml-client

[![Build Status](https://github.com/exxamalte/python-aio-quakeml-client/actions/workflows/ci.yaml/badge.svg?branch=main)](https://github.com/exxamalte/python-aio-quakeml-client/actions?workflow=ci)
[![codecov](https://codecov.io/gh/exxamalte/python-aio-quakeml-client/graph/badge.svg?token=97PBJ93VGE)](https://codecov.io/gh/exxamalte/python-aio-quakeml-client)
[![PyPi](https://img.shields.io/pypi/v/aio-quakeml-client.svg)](https://pypi.python.org/pypi/aio-quakeml-client)
[![Version](https://img.shields.io/pypi/pyversions/aio-quakeml-client.svg)](https://pypi.python.org/pypi/aio-quakeml-client)

This library provides convenient async access to QuakeML feeds.
